"""
tsilva_notebook_utils - Utility functions for Jupyter/Colab notebooks
"""

__version__ = "0.0.123"

# Modules are available for import as: import tsilva_notebook_utils.gymnasium
# We don't import all modules by default to avoid heavy dependencies
